@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright CERN since 2013
+# Copyright European Organization for Nuclear Research (CERN) since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -275,13 +275,12 @@ class ReplicaClient(BaseClient):
         :param files: The list of files. This is a list of DIDs like :
             [{'scope': <scope1>, 'name': <name1>, 'state': <state1>}, {'scope': <scope2>, 'name': <name2>, 'state': <state2>}, ...],
             where a state value can be either of:
-            'A' (available)
-            'S' (suspicious)
-            'U' (unavailable)
-            'R' (recovered)
-            'B' (bad)
-            'L' (lost)
-            'D' (deleted)
+              'A' (AVAILABLE)
+              'U' (UNAVAILABLE)
+              'C' (COPYING)
+              'B' (BEING_DELETED)
+              'D' (BAD)
+              'T' (TEMPORARY_UNAVAILABLE)
         :return: True if replica states have been updated successfully, otherwise an exception is raised.
 
         """
